aboutsummaryrefslogtreecommitdiffstats
path: root/Projects/TempDataLogger
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2010-07-30 08:29:53 +0000
committerDean Camera <dean@fourwalledcubicle.com>2010-07-30 08:29:53 +0000
commit2034141a7eb4d21a738f688b5e35a43793d17fbc (patch)
treee08d9737d2b91825e29bacdce1150d441e6aeb72 /Projects/TempDataLogger
parentfd9b34aac48ad969b9ef9e4a9d7120ae924cec39 (diff)
downloadlufa-2034141a7eb4d21a738f688b5e35a43793d17fbc.tar.gz
lufa-2034141a7eb4d21a738f688b5e35a43793d17fbc.tar.bz2
lufa-2034141a7eb4d21a738f688b5e35a43793d17fbc.zip
Spell check more of the third party libraries used by LUFA.
Diffstat (limited to 'Projects/TempDataLogger')
-rw-r--r--Projects/TempDataLogger/Lib/FATFs/ff.c4
-rw-r--r--Projects/TempDataLogger/Lib/FATFs/ff.h14
-rw-r--r--Projects/TempDataLogger/Lib/FATFs/ffconf.h6
-rw-r--r--Projects/TempDataLogger/TemperatureDataLogger.txt4
4 files changed, 14 insertions, 14 deletions
diff --git a/Projects/TempDataLogger/Lib/FATFs/ff.c b/Projects/TempDataLogger/Lib/FATFs/ff.c
index 7f4cd25fb..6b393747f 100644
--- a/Projects/TempDataLogger/Lib/FATFs/ff.c
+++ b/Projects/TempDataLogger/Lib/FATFs/ff.c
@@ -114,7 +114,7 @@
#endif
-/* Reentrancy related */
+/* Re-entrancy related */
#if _FS_REENTRANT
#if _USE_LFN == 1
#error Static LFN work area must not be used in re-entrant configuration.
@@ -304,7 +304,7 @@ void unlock_fs (
/*-----------------------------------------------------------------------*/
-/* File shareing control functions */
+/* File sharing control functions */
/*-----------------------------------------------------------------------*/
#if _FS_SHARE
diff --git a/Projects/TempDataLogger/Lib/FATFs/ff.h b/Projects/TempDataLogger/Lib/FATFs/ff.h
index d7397042c..4da8dfdbe 100644
--- a/Projects/TempDataLogger/Lib/FATFs/ff.h
+++ b/Projects/TempDataLogger/Lib/FATFs/ff.h
@@ -3,7 +3,7 @@
/----------------------------------------------------------------------------/
/ FatFs module is a generic FAT file system module for small embedded systems.
/ This is a free software that opened for education, research and commercial
-/ developments under license policy of following trems.
+/ developments under license policy of following terms.
/
/ Copyright (C) 2010, ChaN, all right reserved.
/
@@ -266,7 +266,7 @@ typedef char TCHAR;
-/* Definitions corresponds to file shareing feature */
+/* Definitions corresponds to file sharing feature */
#if _FS_SHARE
#if _FS_READONLY
@@ -388,14 +388,14 @@ typedef struct {
typedef enum {
FR_OK = 0, /* (0) Succeeded */
- FR_DISK_ERR, /* (1) A hard error occured in the low level disk I/O layer */
+ FR_DISK_ERR, /* (1) A hard error occurred in the low level disk I/O layer */
FR_INT_ERR, /* (2) Assertion failed */
FR_NOT_READY, /* (3) The physical drive cannot work */
FR_NO_FILE, /* (4) Could not find the file */
FR_NO_PATH, /* (5) Could not find the path */
FR_INVALID_NAME, /* (6) The path name format is invalid */
- FR_DENIED, /* (7) Acces denied due to prohibited access or directory full */
- FR_EXIST, /* (8) Acces denied due to prohibited access */
+ FR_DENIED, /* (7) Access denied due to prohibited access or directory full */
+ FR_EXIST, /* (8) Access denied due to prohibited access */
FR_INVALID_OBJECT, /* (9) The file/directory object is invalid */
FR_WRITE_PROTECTED, /* (10) The physical drive is write protected */
FR_INVALID_DRIVE, /* (11) The logical drive number is invalid */
@@ -403,7 +403,7 @@ typedef enum {
FR_NO_FILESYSTEM, /* (13) There is no valid FAT volume on the physical drive */
FR_MKFS_ABORTED, /* (14) The f_mkfs() aborted due to any parameter error */
FR_TIMEOUT, /* (15) Could not get a grant to access the volume within defined period */
- FR_LOCKED, /* (16) The operation is rejected according to the file shareing policy */
+ FR_LOCKED, /* (16) The operation is rejected according to the file sharing policy */
FR_NOT_ENOUGH_CORE, /* (17) LFN working buffer could not be allocated */
FR_TOO_MANY_OPEN_FILES /* (18) Number of open files > _FS_SHARE */
} FRESULT;
@@ -428,7 +428,7 @@ FRESULT f_truncate (FIL*); /* Truncate file */
FRESULT f_sync (FIL*); /* Flush cached data of a writing file */
FRESULT f_unlink (const TCHAR*); /* Delete an existing file or directory */
FRESULT f_mkdir (const TCHAR*); /* Create a new directory */
-FRESULT f_chmod (const TCHAR*, BYTE, BYTE); /* Change attriburte of the file/dir */
+FRESULT f_chmod (const TCHAR*, BYTE, BYTE); /* Change attribute of the file/dir */
FRESULT f_utime (const TCHAR*, const FILINFO*); /* Change timestamp of the file/dir */
FRESULT f_rename (const TCHAR*, const TCHAR*); /* Rename/Move a file or directory */
#endif
diff --git a/Projects/TempDataLogger/TemperatureDataLogger.txt b/Projects/TempDataLogger/TemperatureDataLogger.txt
index a3729a63d..a76748e38 100644
--- a/Projects/TempDataLogger/TemperatureDataLogger.txt
+++ b/Projects/TempDataLogger/TemperatureDataLogger.txt
@@ -59,8 +59,8 @@
* sampled data. This project will not function correctly if the RTC chip is omitted unless the DUMMY_RTC compile time token
* is specified - see \ref SSec_Options.
*
- * Due to the host's need for exclusive access to the filesystem, the device will not log samples while connected to a host.
- * For the logger to store data, the Dataflash must first be formatted by the host so that it contains a valid FAT filesystem.
+ * Due to the host's need for exclusive access to the file system, the device will not log samples while connected to a host.
+ * For the logger to store data, the Dataflash must first be formatted by the host so that it contains a valid FAT file system.
*
* This project uses the FatFS library from ELM Chan (http://elm-chan.org/fsw/ff/00index_e.html) and the .NET HID device library
* LibHIDNet (http://sourceforge.net/projects/libhidnet/).
diff --git a/Projects/TempDataLogger/Lib/FATFs/ffconf.h b/Projects/TempDataLogger/Lib/FATFs/ffconf.h
index 1087c3a0e..a217b0bf8 100644
--- a/Projects/TempDataLogger/Lib/FATFs/ffconf.h
+++ b/Projects/TempDataLogger/Lib/FATFs/ffconf.h
@@ -163,10 +163,10 @@
/* Include a header file here to define O/S system calls */
/* #include <windows.h>, <ucos_ii.h.h>, <semphr.h> or others. */
/* The _FS_REENTRANT option switches the reentrancy of the FatFs module.
/
-/ 0: Disable reentrancy. _SYNC_t and _FS_TIMEOUT have no effect.
-/ 1: Enable reentrancy. Also user provided synchronization handlers,
+/ 0: Disable re-entrancy. _SYNC_t and _FS_TIMEOUT have no effect.
+/ 1: Enable re-entrancy. Also user provided synchronization handlers,
/ ff_req_grant, ff_rel_grant, ff_del_syncobj and ff_cre_syncobj
/ function must be added to the project. */
@@ -163,10 +163,10 @@
/* Include a header file here to define O/S system calls */
/* #include <windows.h>, <ucos_ii.h.h>, <semphr.h> or others. */
-/* The _FS_REENTRANT option switches the reentrancy of the FatFs module.
+/* The _FS_REENTRANT option switches the re-entrancy of the FatFs module.
/